@@ -64,6 +64,7 @@ class ScimBridgeAgentClientListenerImpl: public ScimBridgeAgentClientListener
 
         bool handle_event (scim_bridge_agent_event_type_t event_type);
 
+        retval_t imengine_status_changed (scim_bridge_imcontext_id_t imcontext_id, bool enabled);
         retval_t set_preedit_shown (scim_bridge_imcontext_id_t imcontext_id, bool shown);
         retval_t set_preedit_cursor_position (scim_bridge_imcontext_id_t imcontext_id, int cursor_position);
         retval_t set_preedit_string (scim_bridge_imcontext_id_t imcontext_id, const WideString &wstring);
@@ -504,6 +505,28 @@ retval_t ScimBridgeAgentClientListenerImpl::set_preedit_mode (scim_bridge_imcont
 
 
 /** Public Funtions **/
+retval_t ScimBridgeAgentClientListenerImpl::imengine_status_changed (scim_bridge_imcontext_id_t imcontext_id, bool enabled)
+{
+    scim_bridge_pdebugln (6, "imengine_status_changed ()");
+
+    ScimBridgeMessage *message = scim_bridge_alloc_message (SCIM_BRIDGE_MESSAGE_IMENGINE_STATUS_CHANGED, 2);
+
+    char *imcontext_id_str;
+    scim_bridge_string_from_uint (&imcontext_id_str, imcontext_id);
+    scim_bridge_message_set_argument (message, 0, imcontext_id_str);
+    free (imcontext_id_str);
+    
+    char *enabled_str;
+    scim_bridge_string_from_boolean (&enabled_str, enabled);
+    scim_bridge_message_set_argument (message, 1, enabled_str);
+    free (enabled_str);
+
+    scim_bridge_messenger_push_message (messenger, message);
+    scim_bridge_free_message (message);
+
+    return RETVAL_SUCCEEDED;
+}
+
 retval_t ScimBridgeAgentClientListenerImpl::set_preedit_shown (scim_bridge_imcontext_id_t imcontext_id, bool shown)
 {
     scim_bridge_pdebugln (6, "set_preedit_shown ()");
@@ -825,7 +848,7 @@ retval_t ScimBridgeAgentClientListenerImpl::delete_surrounding_string (scim_brid
     free (imcontext_id_str);
 
     char *offset_str;
-    scim_bridge_string_from_uint (&offset_str, offset);
+    scim_bridge_string_from_int (&offset_str, offset);
     scim_bridge_message_set_argument (message, 1, offset_str);
     free (offset_str);
 
@@ -931,7 +954,7 @@ retval_t ScimBridgeAgentClientListenerImpl::replace_surrounding_string (scim_bri
     free (str);
 
     char *cursor_position_str;
-    scim_bridge_string_from_uint (&cursor_position_str, cursor_position);
+    scim_bridge_string_from_int (&cursor_position_str, cursor_position);
     scim_bridge_message_set_argument (message, 2, cursor_position_str);
     free (cursor_position_str);
 
