@@ -431,6 +431,10 @@ bool ScimBridgeAgentIMContextImpl::is_enabled ()
 
 void ScimBridgeAgentIMContextImpl::set_enabled (bool new_state)
 {
+    if (enabled != new_state) {
+        client_listener->imengine_status_changed (id, new_state);
+    }
+    
     enabled = new_state;
 
     if (imengine_shared) enabled_by_default = enabled;
@@ -612,6 +616,7 @@ void ScimBridgeAgentIMContextImpl::focus_in ()
         } else {
             enabled = false;
         }
+        client_listener->imengine_status_changed (id, enabled);
     }
 
     panel_listener->focus_in (get_imengine ()->get_factory_uuid ());
